@@ -1,9 +1,13 @@
 
 # from https://github.com/lukemelas/EfficientNet-PyTorch
+# from https://github.com/rwightman/gen-efficientnet-pytorch
 
 from efficientnet_pytorch import EfficientNet
 from torch import nn
+import geffnet.gen_efficientnet as efn
 
+EFNS = [efn.efficientnet_b0, efn.efficientnet_b1, efn.efficientnet_b2, efn.efficientnet_b3,
+        efn.efficientnet_b4, efn.efficientnet_b5, efn.efficientnet_b6, efn.efficientnet_b7]
 
 class Identity(nn.Module):
         def __init__(self):
@@ -13,7 +17,7 @@ class Identity(nn.Module):
                 return x
 
 
-def create_efn(b, weights='imagenet', include_top=False, n_classes=1000):
+def create_efn2(b, weights='imagenet', include_top=False, n_classes=1000):
         if weights == 'imagenet' and include_top and n_classes != 1000:
                 raise ValueError('If using `weights` as `"imagenet"` with `include_top`'
                                  ' as true, `classes` should be 1000')
@@ -28,3 +32,8 @@ def create_efn(b, weights='imagenet', include_top=False, n_classes=1000):
                 model._fc = Identity()
 
         return model
+
+
+def create_efn(b, pretrained=True):
+        model = EFNS[b](pretrained)
+        return model
