@@ -33,6 +33,7 @@ class TorchFitter:
     def __init__(self,
                  model,
                  device,
+                 loss,
                  n_epochs=1,
                  lr=0.0001,
                  scheduler_class=None,
@@ -41,6 +42,8 @@ class TorchFitter:
                  verbose=0,
                  validation_scheduler=True,
                  step_scheduler=False):
+        self.loss_function = loss
+
         self.epoch = 0  # current epoch
         self.n_epochs = n_epochs
         self.verbose = verbose
@@ -126,7 +129,7 @@ class TorchFitter:
         self.model.eval()
         summary_loss = AverageMeter()
         t = time.time()
-        for step, (images, targets, image_ids) in enumerate(val_loader):
+        for step, (images, targets) in enumerate(val_loader):
             if self.verbose:
                 if step % self.verbose == 0:
                     print(
@@ -159,7 +162,7 @@ class TorchFitter:
         t = time.time()
 
         # run epoch
-        for step, (images, targets) in enumerate(train_loader):
+        for step, (images, labels) in enumerate(train_loader):
             if self.verbose > 0:
                 if step % self.verbose == 0:
                     print(
@@ -168,16 +171,17 @@ class TorchFitter:
                         f'time: {(time.time() - t):.5f}', end='\r'
                     )
             # extract images and labels from the dataloader
-            images = torch.stack(images)
             images = images.to(self.device).float()
             batch_size = images.shape[0]
-            labels = [target['labels'].to(self.device).float() for target in targets]
+            labels.to(self.device).float()
 
             self.optimizer.zero_grad()
 
-            loss, _, _ = self.model(images, labels)
-            # print(loss)
+            # Output and loss
+            output = self.model(images)
+            loss = self.loss_function(output, labels)
 
+            # backpropagation
             loss.backward()
 
             summary_loss.update(loss.detach().item(), batch_size)
